@@ -20,7 +20,13 @@ def get_subcollections(collection):
         for subcollection in collection.subcollections:
 
             if attr:=getattr(page, subcollection, None):
-                subcollection_set.add((subcollection, attr))
+                if isinstance(attr, list):
+                    map(
+                            lambda x: subcollection_set.add((subcollection, x)),
+                            attr)
+
+                else:
+                    subcollection_set.add((subcollection, attr))
 
     return subcollection_set
 
@@ -146,7 +152,7 @@ class Site:
 
         if hasattr(collection, 'feeds'):
             for feed in collection.feeds:
-                    self.register_feed(feed=feed, collection=collection)
+                self.register_feed(feed=feed, collection=collection)
 
     def register_feed(self, feed, collection: Collection) -> None:
         extension = self.engines['rss_engine'].extension
@@ -165,14 +171,7 @@ class Site:
     def register_route(self, cls) -> None:
         self.routes.append(cls())
 
-
     def render(self, dry_run: bool = False) -> None:
-        # check for errors
-        if self.SITE_TITLE == "Untitle Site":
-            logging.warning(f"No custom site title defined. Using the {SITE_TITLE=}")
-
-        if self.SITE_URL == "https://example.com":
-            logging.warning(f"No custom site URL defined. Using the {self.SITE_URL=}")
 
         for page in self.routes:
 
@@ -200,4 +199,3 @@ class Site:
                     keys=self.search_keys,
                     filepath=self.output_path.joinpath(self.search_index_filename),
                     )
-
